package datastructure

import (
	"testing"

	c "github.com/smartystreets/goconvey/convey"
)

func TestSplit(t *testing.T) {
	c.Convey("基础用例", t, func() {
		var (
			s = "a:b:c"
			sep = ":"
			expect = []string {"a", "b", "c"}
		)
		// Split 本目录
		got := Split(s, sep)
		c.So(got, c.ShouldResemble, expect) // 断言
	})

	c.Convey("不包含分隔符用例", t, func() {
		var (
			s = "a:b:c"
			sep = "|"
			expect = []string {"a:b:c"}
		)
		got := Split(s, sep)
		c.So(got, c.ShouldResemble, expect) // 断言
	})
}

/*

D:\Go_WorkSpace\pkg\mod\github.com\smartystreets\goconvey@v1.7.2\convey\context.go:6:2: missing go.sum entry for module providing package github.com/jtolds/gls (imported by github.com/smartystreets/goconvey/convey); to add:
	go get github.com/smartystreets/goconvey/convey@v1.7.2
D:\Go_WorkSpace\pkg\mod\github.com\smartystreets\goconvey@v1.7.2\convey\assertions.go:3:8: missing go.sum entry for module providing package github.com/smartystreets/assertions (imported by github.com/smartystreets/goconvey/convey); to add:
	go get github.com/smartystreets/goconvey/convey@v1.7.2

*/


// 1、本目录所欲.go文件都要是统一报名，package algorithms
// 2、不能有func main() 函数，要不测试文件_test.go运行报错!


// 嵌套示例
func TestSplit2(t *testing.T) {
	// 只需要在顶层的Convey测试用例时传入t
	c.Convey("分隔符在开头或结尾用例", t, func() {
		tt := []struct {
			name 	string
			s    	string
			sep  	string
			expect  []string
		}{
			{"分隔符在开头", "*1*2*3", "*", []string{"", "1", "2", "3"}},
			{"分隔符在结尾", "1+2+3+", "+", []string{"1", "2", "3", ""}},
		}
		for _, tc := range tt {
			c.Convey(tc.name, func() {
				// 嵌套调用Convey
				got := Split(tc.s, tc.sep)
				c.So(got, c.ShouldResemble, tc.expect)
			}) // {和)换行的话，报错的!
		}
	})

}


//// 表格驱动测试：
//func TestShortFilename(t *testing.T) {
//	tests :=  []struct {
//		in      string
//		expected string
//	}{
//		{"???", "???"},
//		{"filename.go", "filename.go"},
//		{"hello/filename.go", "filename.go"},
//		{"main/hello/filename.go", "filename.go"},
//	}
//
//	for _, tt := range tests {
//		actual := getShortFilename(tt.in) // getShortFilename 函数没有
//		if strings.Compare(actual, tt.expected) != 0 {
//			t.Fail()
//		}
//	}
//}

// 结合表格测试可以写多个测试用例。testing 本身也可以写表格测试，这里使用 Testify 演示
//func TestCheckUrl3(t *testing.T) {
//
//	assert := assert.New(t)
//
//	var tests = []struct {
//
//		input string
//
//		expected bool
//
//	}{
//
//		{"xdcute.com", true},
//
//		{"xxx.com", false},
//
//	}
//
//	for _, test := range tests {
//
//		fmt.Println(test.input)
//
//		assert.Equal(CheckUrl(test.input), test.expected) // CheckUrl函数没有，报错!!
//
//	}
//
//}
