package main

func getApiHealth() {
    start := time.Now()

    tr := &http.Transport {
        TLSClientConfig: &tls.Config { InsecureSkipVerify: true},
    }
    client := &http.Client {Transport: tr} // 忽略证书校验
    resp, err := client.Get("https://baidu.com/health")

    if err != nil {
        fmt.Println("get error: ", err)
        return
    }

    // defer resp.Body.Close()

    fmt.Println("get resp.Status: ", resp.Status)
    body, err := ioutil.ReadAll(resp.Body)
    fmt.Println("resp.Body", string(resp.Body))

    elapsed := time.Since(start)
    if strings.Contains(resp.Status, "200") {
        bommer.RecordSuccess("https", "/health", elapsed.Nanoseconds()/int64(time.Millisecond), int64(10))
    } else {
        boomer.RecordFailure("https", "/health", elapsed.Nanoseconds()/int64(time.Millisecond), "health not equal 200!")
    }

    defer func(Body io.ReadCloser) {
        err := Body.Close()
        if err != nil {
            fmt.Println("Body.Close() error: ", err)
        }(resp.Body)
    }

}

func postApiWebhook() {
    start := time.Now()

    // post入参
    info := make(map[string] interface {})
    jsonFile := "绝对路径"
    var data, _ = ioutil.ReadFile(jsonFile)
    var err = json.Unmarshal(data, &info)
    if err != nil {
        log.Printf("error: %s\n", err)
        log.Fatal("process json file failed")
        return
    }
    fmt.Println("Bin data:", data)
    fmt.Println("data:", string(data))

    tr := &http.Transport {
        TLSClientConfig: &tls.Config { InsecureSkipVerify: true},
    }
    client := &http.Client {Transport: tr} // 忽略证书校验

    // 将解析之后的数据转为Reader类型
    reader := bytes.NewReader(data)
    resp, _ := client.Post("https://baidu.com/webhook",
        "application/json",
        reader)
    fmt.Println("post resp.Status: ", resp.Status)
    body, _ := ioutil.ReadAll(resp.Body)
    fmt.Println("post resp.Body:", string(resp.Body))

    // boomer 压测用
    elapsed := time.Since(start)

    if strings.Contains(resp.Status, "200") {
        bommer.RecordSuccess("https", "/health", elapsed.Nanoseconds()/int64(time.Millisecond), int64(10))
    } else {
        boomer.RecordFailure("https", "/health", elapsed.Nanoseconds()/int64(time.Millisecond), "health not equal 200!")
    }

    defer func(Body io.ReadCloser) {
        err := Body.Close()
        if err != nil {
            fmt.Println("Body.Close() error: ", err)
        }(resp.Body)
    }

}

func main() {
    task1 := &boomer.Task {
        Name: "health",
        Weight: 20,
        Fn: getApiHealth,
    }

    task2 := &boomer.Task {
        Name: "webhook",
        Weight: 20,
        Fn: postApiWebhook,
    }

    boomer.Run(task1, task2)

}

/*
运行：
cd server & locust -f dummy.py --master --master-bind-host=127.0.0.1 --master-bind-port=5557
cd server & go run apiperformance.go --master-host=127.0.0.1 --master-port=5557
*/

/*
疑问：
1、与locust相比，为啥RPS数量大于设置的用户数？
2、单接口跑。RPS能到2700、3000多，但是，看控制台打印的返回值，都报凑的，为啥？？
*/
